@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -87,10 +85,13 @@ create_face_from_contents (FontLoadJob *job,
                                  &retval);
 
   if (ft_error != 0) {
-    g_set_error_literal (error, G_IO_ERROR, 0,
-                         "Unable to read the font face file");
+    gchar *uri;
+    uri = g_file_get_uri (job->file);
+    g_set_error (error, G_IO_ERROR, 0,
+                 "Unable to read the font face file '%s'", uri);
     retval = NULL;
     g_free (job->face_contents);
+    g_free (uri);
   } else {
     *contents = job->face_contents;
   }
@@ -156,16 +157,20 @@ sushi_new_ft_face_from_uri (FT_Library library,
                             GError **error)
 {
   FontLoadJob *job = NULL;
+  FT_Face face;
 
   job = font_load_job_new (library, uri, NULL, NULL);
   font_load_job_do_load (job, error);
 
   if ((error != NULL) && (*error != NULL)) {
-    g_object_unref (job);
+    font_load_job_free (job);
     return NULL;
   }
 
-  return create_face_from_contents (job, contents, error);
+  face = create_face_from_contents (job, contents, error);
+  font_load_job_free (job);
+
+  return face;
 }
 
 /**
